@@ -52,11 +52,11 @@ App::Dochazka::REST::Model::Schedhistory - schedule history functions
 
 =head1 VERSION
 
-Version 0.072
+Version 0.073
 
 =cut
 
-our $VERSION = '0.072';
+our $VERSION = '0.073';
 
 
 
@@ -214,6 +214,12 @@ sub insert {
 }
 
 
+=head2 update
+
+There is no update method for schedhistory records. Instead, delete and
+re-create.
+
+
 =head2 delete
 
 Instance method. Deletes the record. Returns status object.
